# Gilardi, Fabrizio, "The Temporary Importance of Role Models for Women's Political Representation", American Journal of Political Science
# Code to replicate Table SI3 (Replication of Table 1, with an alternative specification of the connectivity matrix (W) (travel time by car between all pairs of municipalities and absolute difference of population))
# gilardi@ipz.uzh.ch, 2014-06-24

# Set working directory
setwd("../Data/")

# Load packages
library(texreg)

# Load data
d <- read.csv("dataset-full.csv")


###################
# Estimate models #########################################
###################

out.1w <- glm(n.women.cand ~ sl.autodp.n.women.elected + n.women.elected.lagged + n.women.cand.previously.elected + n.men.cand.previously.elected + n.women.cand.lagged + n.people.elected + n.cand + referenda + wom.kr + log.dist.zh + log.pop + kr.svp + steuerfuss + as.factor(stadt.land) + as.factor(year), data=d, family="poisson")
summary(out.1w)

out.2w <- glm(n.women.cand ~ sl.autodp.n.women.elected + n.women.elected.lagged + n.women.cand.previously.elected + n.men.cand.previously.elected + n.women.cand.lagged + n.people.elected + n.cand + referenda + wom.kr + log.dist.zh + log.pop +  kr.svp + steuerfuss + as.factor(stadt.land) + sl.autodp.n.women.elected*as.factor(year), data=d, family="poisson")
summary(out.2w)

out.3w <- glm(n.women.cand ~ sl.autodp.n.women.elected + n.women.elected.lagged + n.women.cand.previously.elected + n.men.cand.previously.elected + n.women.cand.lagged + n.people.elected + n.cand + referenda + wom.kr + log.dist.zh + log.pop +  kr.svp + steuerfuss + as.factor(stadt.land) + n.women.elected.lagged*as.factor(year), data=d, family="poisson")
summary(out.3w)

out.4w <- glm(n.women.cand ~ sl.autodp.n.women.elected + n.women.elected.lagged + n.women.cand.previously.elected + n.men.cand.previously.elected + n.women.cand.lagged + n.people.elected + n.cand + referenda + wom.kr + log.dist.zh + log.pop +  kr.svp + steuerfuss + as.factor(stadt.land) + n.women.elected.lagged*as.factor(year) + sl.autodp.n.women.elected*as.factor(year), data=d, family="poisson")
summary(out.4w)



##############
# Make table ########################################
##############

var.names <- c(
	"(Intercept)",
	"Spatial lag",
	"Nr. xfemale elected ($t-1$)",
	"Nr. xfemale incumbent cand. ($t-1$)",
	"Nr. xmale incumbent cand. ($t-1$)",
	"Nr. xfemale cand. ($t-1$)",
	"Nr. seats",
	"Total nr. candidates",
	"Referenda on gender equality",
	"Support for xfemale in cantonal elec.",
	"Distance from Zurich (log)",
	"Population (log)",
	"Support for conservative party",
	"Tax level",
	"Suburb",
	"Countryside",
	seq(1978, 2010, 4),
	"Spatial lag $xx$ 1978",
	"Spatial lag $xx$ 1982",
	"Spatial lag $xx$ 1986",
	"Spatial lag $xx$ 1990",
	"Spatial lag $xx$ 1994",
	"Spatial lag $xx$ 1998",
	"Spatial lag $xx$ 2002",
	"Spatial lag $xx$ 2006",
	"Spatial lag $xx$ 2010",
	"Nr. xfemale elected ($t-1$) $xx$ 1978",	
	"Nr. xfemale elected ($t-1$) $xx$ 1982",	
	"Nr. xfemale elected ($t-1$) $xx$ 1986",	
	"Nr. xfemale elected ($t-1$) $xx$ 1990",	
	"Nr. xfemale elected ($t-1$) $xx$ 1994",	
	"Nr. xfemale elected ($t-1$) $xx$ 1998",	
	"Nr. xfemale elected ($t-1$) $xx$ 2002",	
	"Nr. xfemale elected ($t-1$) $xx$ 2006",	
	"Nr. xfemale elected ($t-1$) $xx$ 2010"
)

model.names <- c("(1)", "(2)", "(3)", "(4)")

texreg(list(out.1w, out.2w, out.3w, out.4w), single.row=T, center=T, dcolumn=T, custom.coef.names=var.names, custom.model.names=model.names)




