# Gilardi, Fabrizio, "The Temporary Importance of Role Models for Women's Political Representation", American Journal of Political Science
# Code to replicate Table SI3 (Replication of Table 1, with the number of male candidates as the dependent variable)
# gilardi@ipz.uzh.ch, 2014-06-24

# Set working directory
setwd("../Data/")

# Load packages
library(texreg)

# Load data
d <- read.csv("dataset-full.csv")


###################
# Estimate models #########################################
###################

out.1 <- glm(n.men.cand ~ sl.autob.n.men.elected + n.men.elected.lagged + n.women.cand.previously.elected + n.men.cand.previously.elected + n.men.cand.lagged + n.people.elected + n.cand + referenda + wom.kr + log.dist.zh + log.pop + kr.svp + steuerfuss + as.factor(stadt.land) + as.factor(year), data=d, family="poisson")
summary(out.1)

out.2 <- glm(n.men.cand ~ sl.autob.n.men.elected + n.men.elected.lagged + n.women.cand.previously.elected + n.men.cand.previously.elected + n.men.cand.lagged + n.people.elected + n.cand + referenda + wom.kr + log.dist.zh + log.pop +  kr.svp + steuerfuss + as.factor(stadt.land) + sl.autob.n.men.elected*as.factor(year), data=d, family="poisson")
summary(out.2)

out.3 <- glm(n.men.cand ~ sl.autob.n.men.elected + n.men.elected.lagged + n.women.cand.previously.elected + n.men.cand.previously.elected + n.men.cand.lagged + n.people.elected + n.cand + referenda + wom.kr + log.dist.zh + log.pop +  kr.svp + steuerfuss + as.factor(stadt.land) + n.men.elected.lagged*as.factor(year), data=d, family="poisson")
summary(out.3)

out.4 <- glm(n.men.cand ~ sl.autob.n.men.elected + n.men.elected.lagged + n.women.cand.previously.elected + n.men.cand.previously.elected + n.men.cand.lagged + n.people.elected + n.cand + referenda + wom.kr + log.dist.zh + log.pop +  kr.svp + steuerfuss + as.factor(stadt.land) + n.men.elected.lagged*as.factor(year) + sl.autob.n.men.elected*as.factor(year), data=d, family="poisson")
summary(out.4)


##############
# Make table ########################################
##############

var.names <- c(
	"(Intercept)",
	"Spatial lag",
	"Nr. xmale elected ($t-1$)",
	"Nr. xfemale incumbent cand. ($t-1$)",
	"Nr. xmale incumbent cand. ($t-1$)",
	"Nr. xfemale cand. ($t-1$)",
	"Nr. seats",
	"Total nr. candidates",
	"Referenda on gender equality",
	"Support for xfemale in cantonal elec.",
	"Distance from Zurich (log)",
	"Population (log)",
	"Support for conservative party",
	"Tax level",
	"Suburb",
	"Countryside",
	seq(1978, 2010, 4),
	"Spatial lag $xx$ 1978",
	"Spatial lag $xx$ 1982",
	"Spatial lag $xx$ 1986",
	"Spatial lag $xx$ 1990",
	"Spatial lag $xx$ 1994",
	"Spatial lag $xx$ 1998",
	"Spatial lag $xx$ 2002",
	"Spatial lag $xx$ 2006",
	"Spatial lag $xx$ 2010",
	"Nr. xmale elected ($t-1$) $xx$ 1978",
	"Nr. xmale elected ($t-1$) $xx$ 1982",
	"Nr. xmale elected ($t-1$) $xx$ 1986",
	"Nr. xmale elected ($t-1$) $xx$ 1990",
	"Nr. xmale elected ($t-1$) $xx$ 1994",
	"Nr. xmale elected ($t-1$) $xx$ 1998",
	"Nr. xmale elected ($t-1$) $xx$ 2002",
	"Nr. xmale elected ($t-1$) $xx$ 2006",
	"Nr. xmale elected ($t-1$) $xx$ 2010"
)


model.names <- c("(A1)", "(A2)", "(A3)", "(A4)")

texreg(list(out.1, out.2, out.3, out.4), single.row=T, center=T, dcolumn=T, custom.coef.names=var.names, custom.model.names=model.names)
