# Gilardi, Fabrizio, "The Temporary Importance of Role Models for Women's Political Representation", American Journal of Political Science
# Code to replicate Table SI8 (Replication of Table SI4 with the distance from the nearest women’s group as an additional explanatory variable)
# gilardi@ipz.uzh.ch, 2014-06-24

# Set working directory
setwd("../Data/")

# Load packages
library(texreg)

# Load data
d <- read.csv("dataset-full.csv")


###################
# Estimate models #########################################
###################


out.1w <- glm(n.women.cand ~ sl.autob.n.women.elected + n.women.elected.lagged + n.women.cand.previously.elected + n.men.cand.previously.elected + n.women.cand.lagged + n.people.elected + n.cand + referenda + wom.kr + log.dist.zh + log.pop + kr.svp + steuerfuss + as.factor(stadt.land) + dist.fp + as.factor(year), data=d, family="poisson")
summary(out.1w)

out.2w <- glm(n.women.cand ~ sl.autob.n.women.elected + n.women.elected.lagged + n.women.cand.previously.elected + n.men.cand.previously.elected + n.women.cand.lagged + n.people.elected + n.cand + referenda + wom.kr + log.dist.zh + log.pop + kr.svp + steuerfuss + as.factor(stadt.land) + dist.fp * as.factor(year), data=d, family="poisson")
summary(out.2w)

out.3w <- glm(n.women.cand ~ sl.autob.n.women.elected + n.women.elected.lagged + n.women.cand.previously.elected + n.men.cand.previously.elected + n.women.cand.lagged + n.people.elected + n.cand + referenda + wom.kr + log.dist.zh + log.pop + kr.svp + steuerfuss + as.factor(stadt.land) + dist.fp * as.factor(year) + sl.autob.n.women.elected *as.factor(year), data=d, family="poisson")
summary(out.3w)



##############
# Make table ########################################
##############

var.names <- c(
	"(Intercept)",
	"Spatial lag",
	"Nr. xfemale elected ($t-1$)",
	"Nr. xfemale incumbent cand. ($t-1$)",
	"Nr. xmale incumbent cand. ($t-1$)",
	"Nr. xfemale cand. ($t-1$)",
	"Nr. seats",
	"Total nr. candidates",
	"Referenda on gender equality",
	"Support for xfemale in cantonal elec.",
	"Distance from Zurich (log)",
	"Population (log)",
	"Support for conservative party",
	"Tax level",
	"Suburb",
	"Rural",
	"Distance from nearest women's group",
	seq(1978, 2010, 4),
	"Distance from women's group $xx$ 1978",
	"Distance from women's group $xx$ 1982",
	"Distance from women's group $xx$ 1986",
	"Distance from women's group $xx$ 1990",
	"Distance from women's group $xx$ 1994",
	"Distance from women's group $xx$ 1998",
	"Distance from women's group $xx$ 2002",
	"Distance from women's group $xx$ 2006",
	"Distance from women's group $xx$ 2010",
	"Spatial lag $xx$ 1978",
	"Spatial lag $xx$ 1982",
	"Spatial lag $xx$ 1986",
	"Spatial lag $xx$ 1990",
	"Spatial lag $xx$ 1994",
	"Spatial lag $xx$ 1998",
	"Spatial lag $xx$ 2002",
	"Spatial lag $xx$ 2006",
	"Spatial lag $xx$ 2010"
)

model.names <- c("(1)", "(2)", "(3)")

texreg(list(out.1w, out.2w, out.3w), single.row=T, center=T, dcolumn=T, custom.coef.names=var.names, custom.model.names=model.names)
